save_webp_buffer

Function save_webp_buffer 

pub fn save_webp_buffer(
    path: &str,
    bytes: Vec<u8>,
    quality: Option<f32>,
) -> Result<()>
Create a WEBP image buffer given an input of bytes.

This function should be used over save_image_buffer for WEBP because the image library only supports lossless WEBP, while this function uses libwebp for lossy encoding.